@@ -7,7 +7,7 @@ os_fchdir = os.fchdir
 
 class Vim(object):
     @classmethod
-    def initialize(self, vim, classes, channel_id):
+    def initialize(self, vim, classes, channel_id, VimError):
         vim.buffers = RemoteSequence(vim,
                                      classes['buffer'],
                                      lambda: vim.get_buffers())
@@ -25,6 +25,7 @@ class Vim(object):
         vim.options = RemoteMap(lambda k: vim.get_option(k),
                                 lambda k, v: vim.set_option(k, v))
         vim.channel_id = channel_id
+        vim.VimError = VimError
 
     def foreach_rtp(self, cb):
         """
